#!/usr/bin/perl

# Wcal updater from 2.0 to 2.1
# by Joel Savignon

use strict;

my $force = 0;
if ($ARGV[0] eq "-f")
{
    $force = 1;
}

my $wcalddir = "/usr/local/sbin";
print "Wcal updater from 2.0 to 2.1\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $dir = <STDIN>;
chomp($dir);
if ($dir)
{
    $wcalddir = $dir;
}

if (!-e "$wcalddir/wcald")
{
    print "\n*** No $wcalddir/wcald file! ***\n";
    print "Update canceled\n";
    exit 1;
}

my ($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcalddir/wcald");
my $line;
if (!open(WCALD, "$wcalddir/wcald"))
{
    print "\n*** Unable to open $wcalddir/wcald file! ***\n";
    print "Update canceled\n";
    exit 2;
}
my $wcaldvers;
my $wcaldconfdir;
my $wcaldhttpdir;
my $wcalddbdir;
$wcaldmode = $wcaldmode & 0777;

print "wcal uid : $wcalduid\n";
print "wcal gid : $wcaldgid\n";
printf "wcal mod : %o\n", $wcaldmode;

while ($line = <WCALD>)
{
    if ($line =~ /^\#\s*Wcal\s*([\d\.]*)\s*/)
    {
	$wcaldvers = $1;
	print "wcal ver : $wcaldvers\n";
    }
    elsif ($line =~ /^\$::CONF_FILE\s*=\s*\'([^\']*)\/wcal.conf/)
    {
	$wcaldconfdir = $1;
	print "conf dir : $wcaldconfdir\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=\s*\'([^\']*)/)
    {
	$wcaldhttpdir = $1;
	print "http dir : $wcaldhttpdir\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=\s*\'([^\']*)/)
    {
	$wcalddbdir = $1;
	print "data dir : $wcalddbdir\n";
    }
}
close(WCALD);

if (!$force && $wcaldvers != "2.0")
{
    print "\n*** Current version of wcal is not 2.0 ***\n";
    print "Update canceled\n";
    exit 3;
}

print ("Copying wcald\n");
rename("$wcalddir/wcald", "$wcalddir/wcald.2.0");
open(WCALD2, ">$wcalddir/wcald");
open(WCALD, "wcald.in");
while ($line = <WCALD>)
{
    if ($line =~ /^\$::CONF_FILE\s*=/)
    {
	print WCALD2 "\$::CONF_FILE = '$wcaldconfdir/wcal.conf';\n";
    }
    elsif ($line =~ /^\$::MSG_FILE\s*=/)
    {
	print WCALD2 "\$::MSG_FILE = '$wcaldconfdir/wcal.msg';\n";
    }
    elsif ($line =~ /^\$::DEF_FILE\s*=/)
    {
	print WCALD2 "\$::DEF_FILE = '$wcaldconfdir/wcal.def';\n";
    }
    elsif ($line =~ /^\$::SDAYS_FILE\s*=/)
    {
	print WCALD2 "\$::SDAYS_FILE = '$wcaldconfdir/wcal.sdays';\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=/)
    {
	print WCALD2 "\$::DIRECTORY = '$wcaldhttpdir';\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=/)
    {
	print WCALD2 "\$::DB_DIR = '$wcalddbdir';\n";
    }
    else
    {
	print WCALD2 $line;
    }
}
close(WCALD);
close(WCALD2);
chown($wcalduid, $wcaldgid, "$wcalddir/wcald");
chmod($wcaldmode, "$wcalddir/wcald");

print ("Copying wcal.msg\n");
($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldconfdir/wcal.msg");
rename("$wcaldconfdir/wcal.msg","$wcaldconfdir/wcal.msg.2.0");
system("cp wcal.msg $wcaldconfdir/wcal.msg");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.msg");
chmod($wcaldmode, "$wcaldconfdir/wcal.msg");
print ("Copying wcal.def\n");
system("cp wcal.def $wcaldconfdir/wcal.def");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.def");
chmod($wcaldmode, "$wcaldconfdir/wcal.def");
print ("Copying wcal.sdays\n");
system("cp wcal.sdays $wcaldconfdir/wcal.sdays");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.sdays");
chmod($wcaldmode, "$wcaldconfdir/wcal.sdays");

($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldhttpdir/images/background.jpg");
print ("Copying am.gif\n");
system("cp images/am.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/am.gif");
chmod($wcaldmode, "$wcaldconfdir/images/am.gif");
print ("Copying pm.gif\n");
system("cp images/pm.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/pm.gif");
chmod($wcaldmode, "$wcaldconfdir/images/pm.gif");
print ("Copying nt.gif\n");
system("cp images/nt.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/nt.gif");
chmod($wcaldmode, "$wcaldconfdir/images/nt.gif");
print ("Copying todo.gif\n");
system("cp images/todo.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/todo.gif");
chmod($wcaldmode, "$wcaldconfdir/images/todo.gif");
print ("Copying mail.gif\n");
system("cp images/mail.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/mail.gif");
chmod($wcaldmode, "$wcaldconfdir/images/mail.gif");
print ("Copying sday.gif\n");
system("cp images/sday.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/sday.gif");
chmod($wcaldmode, "$wcaldconfdir/images/sday.gif");
print ("Copying reload.gif\n");
system("cp images/reload.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/reload.gif");
chmod($wcaldmode, "$wcaldconfdir/images/reload.gif");
print ("Copying mwdbackground.jpg\n");
system("cp images/mwdbackground.jpg $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/mwdbackground.jpg");
chmod($wcaldmode, "$wcaldconfdir/images/mwdbackground.jpg");
print ("Copying doc files\n");
system("cp -R doc $wcaldhttpdir ; chmod -R 0750 $wcaldhttpdir/doc");

print ("\nWcal successfully updated from 2.0 to 2.1\n");
print ("Restart wcald to make changes available\n");
